pub struct ServeConfig {
pub bind: SocketAddr,
pub root: PathBuf,
pub limits: Limits,
pub static_policy: StaticPolicy,
pub default_content_type: String,
pub extra_response_headers: Vec<(String, String)>,
}Fields
bind: SocketAddrroot: PathBuflimits: Limitsstatic_policy: StaticPolicydefault_content_type: Stringextra_response_headers: Vec<(String, String)>Implementations
Sourceimpl ServeConfig
impl ServeConfig
Sourcepub fn startup_summary(&self) -> StartupSummary
pub fn startup_summary(&self) -> StartupSummary
Build a logging-friendly summary of this configuration.
The binary crate uses this to print a startup banner. Callers that
embed eggserve-core directly can use it for their own logging.