pub enum BodySourceError {
InvalidRange,
AlreadyConsumed,
}Expand description
Errors that can arise when converting a resolved file into a body source.
Variants
InvalidRange
The requested byte range is invalid for the file size.
AlreadyConsumed
The resolved file has already been consumed into a body source.