pub enum HeaderError {
InvalidName,
InvalidValue,
NameTooLong,
}Expand description
Errors from header validation.
Variants
InvalidName
The header name is empty or contains invalid characters.
InvalidValue
The header value contains a carriage return, line feed, or NUL byte.
NameTooLong
The header name is too long.