pub fn validate_method(
method: &str,
) -> Result<ReadOnlyMethod, RequestValidationError>Expand description
Check if a method string is a supported read-only method.
pub fn validate_method(
method: &str,
) -> Result<ReadOnlyMethod, RequestValidationError>Check if a method string is a supported read-only method.