Module request

Module request 

Canonical request envelope.

Request combines the request head, body, and connection metadata into a single transport-independent value. This is the input type for the Service trait.

Structs

Request
A canonical, transport-independent HTTP request.